from ..util.translator import Translator as Translator
from _typeshed import Incomplete

class BaseAPIJSONObjectMeta(type):
    def __init__(cls, name, bases, attrs) -> None: ...

class BaseAPIJSONObject:
    def __init__(self, response_object: Incomplete | None = None, **kwargs) -> None: ...
    def __getitem__(self, item): ...
    def __contains__(self, item) -> bool: ...
    def __iter__(self): ...
    @property
    def object_type(self): ...
    @classmethod
    def untranslated_fields(cls): ...
    @property
    def response_object(self): ...
