from .cloneable import Cloneable as Cloneable
from _typeshed import Incomplete

class BaseEndpoint(Cloneable):
    def __init__(self, session, **kwargs) -> None: ...
    @property
    def session(self): ...
    @property
    def translator(self): ...
    def get_url(self, endpoint, *args): ...
    def clone(self, session: Incomplete | None = None): ...
