from _typeshed import Incomplete

class Cloneable:
    def as_user(self, user): ...
    def with_shared_link(self, shared_link, shared_link_password): ...
    def clone(self, session: Incomplete | None = None) -> None: ...
    @property
    def session(self) -> None: ...
